package simple-diff

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Simple_diffSource

A simple diffing algorithm

Sourcetype diff =
  1. | Deleted of string array
  2. | Added of string array
  3. | Equal of string array

Represents the change or lack of change in a line or character between the old and new version.

Sourcetype t = diff list

List of diffs which is the return value of the main function.

Sourceval get_diff : string array -> string array -> t

Returns a list of diffs between two arrays